import { GetRoleConfig, MergePermissions, TSchemaOptions } from '../types';
import { default as Role } from './role';

/**
 * Auth schema
 */
declare class Schema<T extends {
    [K in keyof T]: T[K] extends Role<infer U> ? Role<U> : never;
}> {
    options: TSchemaOptions<T>;
    constructor(options: TSchemaOptions<T>);
    /**
     * Get roles
     */
    get roles(): T;
    /**
     * Get role by key
     */
    getRole<K extends keyof T>(name: K): T[K];
    /**
     * Get all resources in the schema
     */
    getResources(): Record<keyof MergePermissions<T>, keyof MergePermissions<T>>;
    /**
     * Get all permissions in the schema
     */
    getPermissions<U extends keyof T>(role: U): T[U]["permissions"];
    /**
     * Convert a role into a JSON string, optionally transform the result
     */
    toJSON<K extends keyof T>(role: K): string;
    toJSON<K extends keyof T, R>(role: K, transform: (data: string) => R): R;
    /**
     * Convert a role into an object, optionally transform the result
     */
    toObject<K extends keyof T>(role: K): GetRoleConfig<T[K]>;
    toObject<K extends keyof T, R>(role: K, transform: (data: GetRoleConfig<T[K]>) => R): R;
    /**
     * Check if a role exists in the schema
     */
    exists(role: keyof T | (string & {})): boolean;
}
export default Schema;
