import { MergeObjects } from '../types/utils.types';

declare const utils: {
    merge: <T extends Record<string, any>, U extends Record<string, any>>(a: T | null | undefined, b: U | null | undefined, options?: {
        /**
         * If true, the merge will not override the existing properties
         */
        preserve?: boolean;
    }) => MergeObjects<T, U>;
    omit<T extends Record<string, any>, K extends keyof T>(obj: T, keys: K[]): Record<string, any>;
    pick<T extends Record<string, any>, K extends keyof T>(obj: T, keys: K[]): Record<string, any>;
    overlaps<T extends Record<string, any>, U extends Record<string, any>>(a: T, b: U): string[];
    seialize<T extends Record<string, any>>(obj: T): string;
    deserialize<T extends Record<string, any>>(json: string): T;
    validate: {
        notNull: (value: any, error: string, errors?: string[]) => void;
        string: (value: any, error: string, errors?: string[]) => void;
        object: (value: any, error: string, errors?: string[]) => void;
        number: (value: any, error: string, errors?: string[]) => void;
        notEmpty: (value: any, error: string, errors?: string[]) => void;
    };
    throwErr: (errors: string[]) => never;
    getValue: <T extends Record<string, any>, K extends keyof T>(obj: T, key: K, defaultValue?: T[K]) => NonNullable<T[K]> | null;
    /**
     * If the args is an array, it returns the array, otherwise it returns an array with the args as the only element
     */
    asArray<T>(args: T | T[]): T[];
};
export default utils;
